@@ -59,7 +59,7 @@ def _format_kwargs(func):
 ##==============================================================#
 
 #: Library version string.
-__version__ = "0.16.1"
+__version__ = "0.16.3"
 
 #: A menu entry that can call a function when selected.
 MenuEntry = namedtuple("MenuEntry", "name desc func args krgs")
@@ -152,7 +152,7 @@ class Menu:
         show_kwargs.update(kwargs)
         return show_menu(self.entries, **show_kwargs)
     def get(self, name):
-        """Gets the entry associated with the given `name`."""
+        """Gets the MenuEntry associated with the given `name`."""
         for entry in self.entries:
             if entry.name == name:
                 return entry
@@ -195,6 +195,8 @@ class Menu:
                 note = "Menu does not loop, single entry."
                 try:
                     result = self.show(note=note, **kwargs)
+                    if result in quit:
+                        return None
                 except EOFError:
                     pass
             return result
@@ -206,7 +208,14 @@ class Menu:
                 return _main()
 
 class Wrap(object):
-    """Context manager that wraps content between horizontal lines."""
+    """Context manager that wraps content between horizontal lines.
+
+    **Examples**:
+    ::
+
+        with qprompt.Wrap():
+            qprompt.echo("Hello world!")
+    """
     @_format_kwargs
     def __init__(self, width=None, char="", **kwargs):
         hdr = kwargs.get('hdr', "")
@@ -323,19 +332,19 @@ def show_limit(entries, **kwargs):
 
 @_format_kwargs
 def show_menu(entries, **kwargs):
-    """Shows a menu with the given list of `MenuEntry` items.
+    """Shows a menu with the given list of MenuEntry items.
 
     **Params**:
       - header (str) - String to show above menu.
       - note (str) - String to show as a note below menu.
       - msg (str) - String to show below menu.
       - dft (str) - Default value if input is left blank.
-      - compact (bool) - If true, the menu items will not be displayed
-        [default: False].
-      - returns (str) - Controls what part of the menu entry is returned,
-        'func' returns function result [default: name].
-      - limit (int) - If set, limits the number of menu entries show at a time
-        [default: None].
+      - compact (bool) - If true, the menu items will not be displayed.
+        [default: False]
+      - returns (str) - Controls what part of the MenuEntry is returned,
+        'func' returns function result. [default: name]
+      - limit (int) - If set, limits the number of menu entries show at a time.
+        [default: None]
       - fzf (bool) - If true, can enter FCHR at the menu prompt to search menu.
     """
     global _AUTO
@@ -442,7 +451,8 @@ def ask(msg="Enter input", fmt=None, dft=None, vld=None, shw=True, blk=False, hl
       - dft (int|float|str) - Default value if input is left blank.
       - vld ([int|float|str|func]) - Valid input entries.
       - shw (bool) - If true, show the user's input as typed.
-      - blk (bool) - If true, accept a blank string as valid input. Note that
+      - blk (bool) - If true, accept a blank string as valid input; blank input
+        will be accepted even if the `vld` parameter is supplied. Note that
         supplying a default value will disable accepting blank input.
     """
     global _AUTO
@@ -595,6 +605,7 @@ def status(*args, **kwargs):
 
     **Examples**:
     ::
+
         @qprompt.status("Something is happening...")
         def do_something(a):
             time.sleep(a)
@@ -671,6 +682,7 @@ def wrap(item, args=None, krgs=None, **kwargs):
 
     **Examples**:
     ::
+
         qprompt.wrap("Hi, this will be wrapped.")  # String item.
         qprompt.wrap(myfunc, [arg1, arg2], {'krgk': krgv})  # Func item.
     """
@@ -683,7 +695,7 @@ def wrap(item, args=None, krgs=None, **kwargs):
             echo(item)
 
 def _guess_name(desc, taken=None):
-    """Attempts to guess the menu entry name from the function name."""
+    """Attempts to guess the MenuEntry name from the function name."""
     taken = taken or []
     name = ""
     # Try to find the shortest name based on the given description.
@@ -702,7 +714,7 @@ def _guess_name(desc, taken=None):
     return name
 
 def _guess_desc(fname):
-    """Attempts to guess the menu entry description from the function name."""
+    """Attempts to guess the MenuEntry description from the function name."""
     return fname.title().replace("_", " ")
 
 ##==============================================================#
